@@ -1,5 +1,4 @@
 import json
-import os
 
 """
 This is the config yaml:
@@ -22,10 +21,10 @@ This is the config yaml:
    'Test_id_2': 'Times New Roman',
 ...
 """
-env = "DEV"
+env = "PROD"
 # Opening default options JSON file
 if env == "DEV":
-    data_dir = "data_cache"
+    data_dir = "data_test"
 else:
     data_dir = "/data"
 
@@ -46,7 +45,8 @@ model_name = "Base"
 model_version = "0.0.0"
 model_name_version = f"{model_name}_{model_version}"
 
-def extract_float_sensors(sensors:list):
+
+def extract_float_sensors(sensors: list):
     float_sensors_types = ["lux"]
     float_sensors = []
     for sensor in sensors:
@@ -54,4 +54,7 @@ def extract_float_sensors(sensors:list):
             float_sensors.append(sensor)
     return float_sensors
 
-float_sensors = extract_float_sensors(sensors)
\ No newline at end of file
+
+float_sensors = extract_float_sensors(sensors)
+
+output_list = ["entity_id", "state", "last_changed"]
